@@ -68,3 +68,6 @@ hce_dat <- hce::simHCE(n = 2500, TTE_A = Rates_A, TTE_P = Rates_P,
 plot(hce_dat, compute_win_odds = TRUE, lowerBetter = TRUE,
      trans = "reverse")
 
+## ----maraca12, eval = TRUE, fig.width = 7, fig.height = 6---------------------
+plot(mar, continuous_grid_spacing_x = 20, remove_outliers = TRUE)
+
